@@ -15,10 +15,10 @@ from http_tools.long_requests_middleware import first
 from init_helpers import conditional_set
 from init_helpers.dict_to_dataclass import dict_to_dataclass
 
+from .entity_order import entity_order_as_dict, EntityOrder
+from .entity_condition import EntityCondition, entity_condition_as_dict
 from .entity_dataclass import Entity, prepare_entity_column_names, is_entity_dataclass
 from .to_list import to_list
-from .entity_elements import entity_condition_as_dict, entity_order_as_dict, EntityOrderProtocol, \
-    EntityConditionProtocol
 
 
 logger = logging.getLogger(__name__)
@@ -37,9 +37,9 @@ class EntityServerConnector:
 
     async def get_one(self,
                       entity_type: Type[Entity],
-                      filter_by: EntityConditionProtocol | list[EntityConditionProtocol] | None = None,
-                      search_by: EntityConditionProtocol | list[EntityConditionProtocol] | None = None,
-                      order_by: EntityOrderProtocol | list[EntityOrderProtocol] | None = None) -> Entity:
+                      filter_by: EntityCondition | list[EntityCondition] | None = None,
+                      search_by: EntityCondition | list[EntityCondition] | None = None,
+                      order_by: EntityOrder | list[EntityOrder] | None = None) -> Entity:
         entities = await self.get_list(entity_type, filter_by, search_by, order_by, limit=1)
         if not entities:
             raise LookupError(f'Undefined {entity_type.__entity_name__}')
@@ -47,9 +47,9 @@ class EntityServerConnector:
 
     async def get_list(self,
                        entity_type: Type[Entity],
-                       filter_by: EntityConditionProtocol | list[EntityConditionProtocol] | None = None,
-                       search_by: EntityConditionProtocol | list[EntityConditionProtocol] | None = None,
-                       order_by: EntityOrderProtocol | list[EntityOrderProtocol] | None = None,
+                       filter_by: EntityCondition | list[EntityCondition] | None = None,
+                       search_by: EntityCondition | list[EntityCondition] | None = None,
+                       order_by: EntityOrder | list[EntityOrder] | None = None,
                        offset: int = 0,
                        limit: int = 10 ** 6) -> list[Entity]:
         if not is_entity_dataclass(entity_type):
@@ -97,7 +97,7 @@ class EntityServerConnector:
 
     async def delete(self,
                      entity_type: Type[Entity],
-                     filter_by: EntityConditionProtocol | list[EntityConditionProtocol]) -> bool:
+                     filter_by: EntityCondition | list[EntityCondition]) -> bool:
         if not is_entity_dataclass(entity_type):
             raise TypeError("expected entity_dataclass type")
 
